@@ -1,7 +1,7 @@
 #coding: utf-8
 '''
-    django-photo-albums provides base class (photo_albums.test_utils.AlbumTest) for 
-    writing integration tests for app instances. 
+    django-photo-albums provides base class (photo_albums.test_utils.AlbumTest) 
+    for writing integration tests for app instances. 
     
     The example usage::
     
@@ -30,8 +30,9 @@
             # if slugs are in use:
             # album_for_id = 'my_object_slug'
             
-            # id's of various images: 2 images in album (second is nedded if tou want 
-            # to test reordering) and one image in other album to test permission checks
+            # id's of various images: 2 images in album (second is nedded if you
+            # want to test reordering) and one image in other album to test
+            # permission checks
             image_in_album_id = 48
             image2_in_album_id = 66
             image_in_other_album_id = 42    
@@ -48,19 +49,40 @@ from generic_images.models import AttachedImage
 class AlbumTest(ViewTest):
         
     username = None
+    "existing user's username"
+
     password = None
+    "existing user's password"
+    
     fixtures = []
+    """ fixtures to be loaded (at least with users, images and
+        objects with galleries)
+    """
+    
     album_site = None
+    " ``PhotoAlbumSite`` instance to be tested "
+    
     excluded_views = []
+    " a list of names of excluded views. Excluded views won't be tested. "
     
     album_for_id = None
+    " object id (or slug) for which album is attached to "
+    
     non_existing_object_id = 0
     
+    image2_in_album_id = None    
+    " "
+    
     image_in_album_id = None
-    image2_in_album_id = None
+    " "
+    
     image_in_other_album_id = None
-    non_existing_image_id = 0
-            
+    """ id's of various images: 2 images in album (second is nedded if tou 
+        want to test reordering) and one image in other album to test 
+        permission checks
+    """
+    
+    non_existing_image_id = 0            
     
     def check(self, view, status, kwargs=None):
         if not kwargs:
