@@ -18,18 +18,18 @@
     Included urls looks like ``<object_id>/<app_name>/<action>`` or 
     ``<object_id>/<app_name>/<image_id>/<action>``,
     where object_id is the id of object which is gallery attached to, 
-    app_name is "albums" by default, image_id is image id :) and action 
-    is performed action (view, edit, etc). It is possible to use slug 
-    instead of object's id (look at ``object_regex`` and ``lookup_field`` 
-    parameters). 
+    app_name is "album" by default (you can change it :ref:`here<app_name_param>`), 
+    image_id is image id :-) and action is the performed action (view, edit, etc). 
+    It is possible to use slug instead of object's id 
+    (look at ``object_regex`` and ``lookup_field`` :ref:`parameters<custom_url_scheme>`). 
     
-    2. Create the necessary templates. 
+    2. Create the necessary templates.
        
     3. Link people to image gallery using ``{% url .. %}`` template tags.
     
-    You can use these urls (assuming that `user_images` in an instance name,
-    `album_user` is object for which gallery is attached to, `image` is image 
-    in gallery)::
+    You can use these urls (assuming that ``user_images`` is an instance name,
+    ``album_user`` is the object for which gallery is attached to, ``image`` is an image 
+    in gallery and slugs are not used)::
     
         {% url user_images:show_album album_user.id %}
         
@@ -38,6 +38,8 @@
         {% url user_images:upload_main_image album_user.id %}
         
         {% url user_images:upload_images album_user.id %}
+
+        {% url user_images:upload_zip album_user.id %}
         
         {% url user_images:show_image album_user.id image.id %}
         
@@ -57,53 +59,74 @@
 
 from django.conf.urls.defaults import *
 from generic_utils.app_utils import PluggableSite
-from photo_albums.forms import ImageEditForm, PhotoFormSet
+from photo_albums.forms import ImageEditForm, PhotoFormSet, UploadZipAlbumForm
 from generic_images.forms import AttachedImageForm
 
 class PhotoAlbumSite(PluggableSite):
-    '''
-        Constructor parameters:
-        
-        ``instance_name``: String. Required. App instance name for url 
-        reversing. Must be unique.
-        
-        ``queryset``: QuerySet. Required. Albums will be attached to objects 
-        in this queryset.
-        
-        ``object_regex``: String. Optional, default is '\d+'. It should be a 
-        URL regular expression for object in URL. You should use smth. 
-        like '[\w\d-]+' for slugs.
-        
-        ``lookup_field``: String. Optional, default is 'pk'. It is a field 
-        name to lookup. It may contain ``__`` and follow relations 
-        (ex.: `userprofile__slug`).
-        
-        ``app_name``: String. Optional, default value is 'album'. Used by url 
-        namespaces stuff.
-        
-        ``extra_context``: Dict. Optional. Extra context that will be passed 
-        to each view.
-        
-        ``template_object_name``: String. Optional. The name of template 
-        context variable with object for which album is attached. 
-        Default is 'object'.
-        
-        ``has_edit_permission``: Optional. Function that accepts request and 
-        object and returns True if user is allowed to edit album for 
-        object and False otherwise. Default behaviour is to always 
-        return True.
-        
-        ``context_processors``: Optional. A list of callables that will be 
-        used as additional context_processors in each view    
+    '''        
+    Constructor parameters:
+    
+    ``instance_name``: String. Required. App instance name for url 
+    reversing. Must be unique.
+    
+    ``queryset``: QuerySet. Required. Albums will be attached to objects 
+    in this queryset.
+    
+    .. _custom_url_scheme:
+    
+    ``object_regex``: String. Optional, default is ``'\d+'``. It should be a 
+    URL regular expression for object in URL. You should use smth. 
+    like ``'[\w\d-]+'`` for slugs.
+    
+    ``lookup_field``: String. Optional, default is ``'pk'``. It is a field 
+    name to lookup. It may contain ``__`` and follow relations 
+    (ex.: ``userprofile__slug``).
+    
+    .. _app_name_param:
+    
+    ``app_name``: String. Optional, default value is ``'album'``. Used by url 
+    namespaces stuff.
+    
+    ``extra_context``: Dict. Optional. Extra context that will be passed 
+    to each view.
+   
+   .. _template_object_name:
+    
+    ``template_object_name``: String. Optional. The name of template 
+    context variable with object for which album is attached. 
+    Default is ``'object'``.
+    
+    ``has_edit_permission``: Optional. Function that accepts request and 
+    object and returns True if user is allowed to edit album for 
+    object and False otherwise. Default behaviour is to always 
+    return True.
+    
+    ``context_processors``: Optional. A list of callables that will be 
+    used as additional context_processors in each view.    
 
-        ``edit_form_class``: Optional. ModelForm subclass to be used in 
-        edit_image view
-        
-        ``upload_form_class``: Optional. ModelForm subclass to be used in 
-        upload_main_image view
-        
-        ``upload_formset_class``: Optional. ModelFormSet to be used in 
-        upload_images view
+    .. _edit_form_class:
+    
+    ``edit_form_class``: Optional, default is 
+    :class:`~photo_albums.forms.ImageEditForm`. ModelForm subclass to be used in 
+    :func:`~photo_albums.views.edit_image` view.
+    
+    .. _upload_form_class:
+    
+    ``upload_form_class``: Optional, default is ``AttachedImageForm`` (defined in 
+    ``generic_images.forms`` module). ModelForm subclass to be used in 
+    :func:`~photo_albums.views.upload_main_image` view.
+    
+    .. _upload_formset_class:
+    
+    ``upload_formset_class``: Optional, default is 
+    :ref:`PhotoFormSet<photoformset>`. ModelFormSet to be used in 
+    :func:`~photo_albums.views.upload_images` view.
+    
+    .. _upload_zip_form_class:
+    
+    ``upload_zip_form_class``: Optional, default is 
+    :class:`~photo_albums.forms.UploadZipAlbumForm`. Form to be used in 
+    :func:`~photo_albums.views.upload_zip` view. 
         
     '''        
                     
@@ -114,10 +137,12 @@ class PhotoAlbumSite(PluggableSite):
                  context_processors=None,
                  edit_form_class = ImageEditForm,
                  upload_form_class = AttachedImageForm,
-                 upload_formset_class = PhotoFormSet):
+                 upload_formset_class = PhotoFormSet,
+                 upload_zip_form_class = UploadZipAlbumForm):
         self.edit_form_class = edit_form_class
         self.upload_form_class = upload_form_class
         self.upload_formset_class = upload_formset_class
+        self.upload_zip_form_class = upload_zip_form_class
             
         super(PhotoAlbumSite, self).__init__(instance_name, queryset, app_name, 
                                              object_regex, lookup_field,                                             
@@ -141,17 +166,23 @@ class PhotoAlbumSite(PluggableSite):
                             name = 'edit_album',
                         ),
                         url(
-                            self.make_regex(r'/upload_main/'),                            
+                            self.make_regex(r'/upload-main/'),                            
                             'upload_main_image',
                             {'album_site': self},
                             name = 'upload_main_image',
                         ),
                         url(
-                            self.make_regex(r'/upload_images/'),
+                            self.make_regex(r'/upload-images/'),
                             'upload_images',
                             {'album_site': self},
                             name = 'upload_images',
                         ),
+                        url(
+                            self.make_regex(r'/upload-zip/'),
+                            'upload_zip',
+                            {'album_site': self},
+                            name = 'upload_zip',
+                        ),
                         
                         
                         #one image views
@@ -194,7 +225,7 @@ class PhotoAlbumSite(PluggableSite):
                             name = 'reorder_images',
                         ),
                         url(
-                            self.make_regex(r'/set_image_order'),
+                            self.make_regex(r'/set-image-order'),
                             'set_image_order', 
                             {'album_site': self},
                             name = 'set_image_order',
