@@ -1,5 +1,5 @@
 '''
-Views for use with PhotoAlbumSite. 
+Views used by PhotoAlbumSite. 
 '''
 
 from django.conf import settings
@@ -18,7 +18,7 @@ from django.contrib.contenttypes.models import ContentType
 from annoying.decorators import ajax_request
 from annoying.utils import HttpResponseReload
 
-from photo_albums.forms import PhotoFormSet
+from photo_albums.forms import PhotoFormSet, UploadZipAlbumForm
 from generic_images.forms import AttachedImageForm
 from generic_images.models import AttachedImage
 from generic_utils import get_template_search_list
@@ -35,6 +35,7 @@ def show_album(request, object_id, album_site, template_name='show_album.html'):
     
     images = AttachedImage.objects.for_model(object)
     context.update({'images': images})
+    
     return render_to_response(_get_template_names(object, template_name), 
                               context,
                               context_instance=RequestContext(request, processors=album_site.context_processors),
@@ -43,7 +44,7 @@ def show_album(request, object_id, album_site, template_name='show_album.html'):
 
 @login_required
 def edit_album(request, object_id, album_site, template_name='edit_album.html'):
-    ''' same as ``show_album`` view but with login_required decorator '''
+    ''' Show album for object using edit_album.html template, with permission checks. '''
     
     object, context = album_site.get_object_and_context(object_id)
     album_site.check_permissions(request, object)
@@ -59,7 +60,7 @@ def edit_album(request, object_id, album_site, template_name='edit_album.html'):
     
 @login_required
 def upload_main_image(request, object_id, album_site):    
-    ''' upload 1 image and make it main image in gallery '''
+    ''' Upload 1 image and make it main image in gallery '''
     
     object, context = album_site.get_object_and_context(object_id)
     album_site.check_permissions(request, object)
@@ -86,10 +87,37 @@ def upload_main_image(request, object_id, album_site):
                                 context_instance=RequestContext(request, processors=album_site.context_processors),
                              )
 
+@login_required
+def upload_zip(request, object_id, album_site):
+    ''' Upload zip archive with images, extract them, check if they are correct 
+        and attach to object. Redirect to ``show_album`` view on success.
+    '''
+    
+    obj, context = album_site.get_object_and_context(object_id)
+    album_site.check_permissions(request, obj)
+    
+    form_class = album_site.upload_zip_form_class    
+    
+    if request.method == 'POST':
+        form = form_class(request.user, obj, request.POST, request.FILES)
+        if form.is_valid():
+            form.process_zip_file()
+            success_url = album_site.reverse('show_album', args=[object_id])
+            return HttpResponseRedirect(success_url)        
+    else:
+        form = form_class(request.user, obj)
+        
+    context.update({'form': form})
+        
+    return render_to_response(
+                                _get_template_names(obj, 'upload_zip.html'),
+                                context,
+                                context_instance=RequestContext(request, processors=album_site.context_processors),
+                             )
 
 @login_required
 def upload_images(request, object_id, album_site):    
-    ''' upload several images at once '''
+    ''' Upload several images at once '''
     
     object, context = album_site.get_object_and_context(object_id)
     album_site.check_permissions(request, object)
@@ -127,7 +155,7 @@ def _one_image_context(image_id, object):
 
 
 def show_image(request, object_id, image_id, album_site):
-    '''  show one image '''
+    '''  Show one image '''
     
     object, context = album_site.get_object_and_context(object_id)        
     context.update(_one_image_context(image_id, object))
@@ -138,7 +166,7 @@ def show_image(request, object_id, image_id, album_site):
 
 @login_required
 def edit_image(request, object_id, image_id, album_site): 
-    ''' show one image, use login_required decorator and provide edit form '''   
+    ''' Show one image. Checks permissions and provides edit form. '''   
     
     object, context = album_site.get_object_and_context(object_id)
     album_site.check_permissions(request, object)
@@ -161,7 +189,7 @@ def edit_image(request, object_id, image_id, album_site):
 
 @login_required
 def delete_image(request, object_id, image_id, album_site):
-    ''' delete image if request method is POST, displays 
+    ''' Delete image if request method is POST, displays 
         ``confirm_delete.html`` template otherwise 
     '''
     object, context = album_site.get_object_and_context(object_id)
@@ -182,7 +210,7 @@ def delete_image(request, object_id, image_id, album_site):
     
 @login_required
 def set_as_main_image(request, object_id, image_id, album_site):
-    ''' mark image as main and redirect to ``show_image`` view '''
+    ''' Mark image as main and redirect to ``show_image`` view '''
     object, context = album_site.get_object_and_context(object_id)
     album_site.check_permissions(request, object)
     
@@ -196,7 +224,7 @@ def set_as_main_image(request, object_id, image_id, album_site):
     
 @login_required
 def clear_main_image(request, object_id, image_id, album_site):
-    ''' mark image as not main and redirect to ``show_image`` view '''
+    ''' Mark image as not main and redirect to ``show_image`` view '''
     object, context = album_site.get_object_and_context(object_id)
     album_site.check_permissions(request, object)
 
